@@ -1,5 +1,5 @@
 from enum import Enum
-
+from typing import List, Optional
 from telescope_sdk.common import UserFacingDataType
 from pydantic import BaseModel
 from telescope_sdk.company import CompanySizeRange
@@ -17,20 +17,21 @@ class ExampleCompany(BaseModel):
 
 
 class IdealCustomerProfile(BaseModel):
-    example_companies: list[ExampleCompany]
-    job_titles: list[str]
-    keywords: list[str] = None
-    negative_keywords: list[str] = None
-    country_codes: list[list[str]] = None
-    employee_country_codes: list[list[str]] = None
-    industries: list[str] = None
+    example_companies: List[ExampleCompany]
+    job_titles: List[str]
+    keywords: List[str] = None
+    negative_keywords: List[str] = None
+    country_codes: List[List[str]] = None
+    employee_country_codes: List[List[str]] = None
+    industries: List[str] = None
     company_size_range: CompanySizeRange = None
-    company_types: list[str] = None
+    company_types: List[str] = None
 
 
 class Campaign(UserFacingDataType):
     name: str
     status: CampaignStatus
-    sequence_id: str
+    sequence_id: Optional[str] = None
+    outreach_enabled: Optional[bool] = None
     replenish: bool
     icp: IdealCustomerProfile
