@@ -1,4 +1,4 @@
-from typing import Optional, Dict
+from typing import Optional, Dict, List
 
 from pydantic import BaseModel
 
@@ -8,8 +8,8 @@ from telescope_sdk.utils import convert_pdl_company_type_to_company_type, get_cu
 
 
 class CompanyEnrichment(BaseModel):
-    company_summary: Optional[dict]
-    tags: Optional[list[dict]]
+    company_summary: Optional[str]
+    tags: Optional[List[dict]]
 
 
 class CompanySizeRange(BaseModel):
@@ -23,22 +23,25 @@ class Company(IngestedDataType):
     linkedin_url: str
     pdl_id: Optional[str] = None
     universal_name_id: Optional[str] = None
-    tagline: Optional[str] = None
-    description: Optional[str] = None
+    tagline: Optional[str] = None  # might be translated
+    original_tagline: Optional[str] = None
+    description: Optional[str] = None  # might be translated
+    original_description: Optional[str] = None
     domain_name: Optional[str] = None
     website: Optional[str] = None
     landing_page_content: Optional[str] = None
     logo_url: Optional[str] = None
-    embeddings: Optional[list[float]] = None
+    embeddings: Optional[List[float]] = None
     industry: Optional[str] = None
-    categories: Optional[list[str]] = None
-    specialties: Optional[list[str]] = None
+    categories: Optional[List[str]] = None
+    specialties: Optional[List[str]] = None
     company_type: Optional[CompanyType] = None
     company_size_range: Optional[CompanySizeRange] = None
+    est_revenue_range: Optional[str] = None
     company_size_on_linkedin: Optional[int] = None
     founded_year: Optional[int] = None
     hq: Optional[Location] = None
-    locations: Optional[list[Location]] = None
+    locations: Optional[List[Location]] = None
     last_enriched_at: Optional[str] = None
     telescope_icp: Optional[bool] = None
     uprank: Optional[int] = None
@@ -81,6 +84,7 @@ class Company(IngestedDataType):
                 lower=int(pdl_company_size_range_split[0]),
                 upper=int(pdl_company_size_range_split[1])
             ) if pdl_company_size_range_split and len(pdl_company_size_range_split) == 2 else None,
+            est_revenue_range=pdl_input.get('inferred_revenue'),
             company_size_on_linkedin=pdl_input.get('employee_count'),
             founded_year=pdl_input.get('founded'),
             hq=Location.from_pdl(pdl_location) if pdl_location else None,
